@@ -1,12 +1,18 @@
+import logging
+
 from web_framework_v2.http import HttpRequest, ContentType
 from web_framework_v2.http.http_method import HttpMethod
 from web_framework_v2.http_server import HttpServer
 from web_framework_v2.route import Endpoint
 from web_framework_v2.route.endpoint_map import EndpointMap
 
+logger = logging.getLogger(__name__)
+
 
 class Framework:
-    def __init__(self, static_folder: str, static_url_path: str):
+    def __init__(self, static_folder: str, static_url_path: str, log_level=logging.INFO):
+        logging.getLogger("web_framework_v2").setLevel(log_level)
+
         self._static_folder = static_folder
         self._static_url_path = static_url_path
         self._active = False
